# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: depot/buildkit/v1/buildkit.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n depot/buildkit/v1/buildkit.proto\x12\x11\x64\x65pot.buildkit.v1\"U\n\x12GetEndpointRequest\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12-\n\x08platform\x18\x02 \x01(\x0e\x32\x1b.depot.buildkit.v1.Platform\"\xf5\x02\n\x13GetEndpointResponse\x12K\n\x07pending\x18\x01 \x01(\x0b\x32\x38.depot.buildkit.v1.GetEndpointResponse.PendingConnectionH\x00\x12I\n\x06\x61\x63tive\x18\x02 \x01(\x0b\x32\x37.depot.buildkit.v1.GetEndpointResponse.ActiveConnectionH\x00\x1a\x13\n\x11PendingConnection\x1a\xa2\x01\n\x10\x41\x63tiveConnection\x12\x10\n\x08\x65ndpoint\x18\x01 \x01(\t\x12\x13\n\x0bserver_name\x18\x02 \x01(\t\x12\x30\n\x04\x63\x65rt\x18\x03 \x01(\x0b\x32\".depot.buildkit.v1.CertificatePair\x12\x35\n\x07\x63\x61_cert\x18\x04 \x01(\x0b\x32$.depot.buildkit.v1.PublicCertificateB\x0c\n\nconnection\"Y\n\x16ReleaseEndpointRequest\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12-\n\x08platform\x18\x02 \x01(\x0e\x32\x1b.depot.buildkit.v1.Platform\"\x19\n\x17ReleaseEndpointResponse\"!\n\x11PublicCertificate\x12\x0c\n\x04\x63\x65rt\x18\x01 \x01(\t\"\x19\n\nPrivateKey\x12\x0b\n\x03key\x18\x01 \x01(\t\"q\n\x0f\x43\x65rtificatePair\x12\x32\n\x04\x63\x65rt\x18\x01 \x01(\x0b\x32$.depot.buildkit.v1.PublicCertificate\x12*\n\x03key\x18\x02 \x01(\x0b\x32\x1d.depot.buildkit.v1.PrivateKey\"V\n\x13ReportHealthRequest\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12-\n\x08platform\x18\x02 \x01(\x0e\x32\x1b.depot.buildkit.v1.Platform\"\x16\n\x14ReportHealthResponse*L\n\x08Platform\x12\x18\n\x14PLATFORM_UNSPECIFIED\x10\x00\x12\x12\n\x0ePLATFORM_AMD64\x10\x01\x12\x12\n\x0ePLATFORM_ARM64\x10\x02\x32\xbe\x02\n\x0f\x42uildKitService\x12^\n\x0bGetEndpoint\x12%.depot.buildkit.v1.GetEndpointRequest\x1a&.depot.buildkit.v1.GetEndpointResponse0\x01\x12\x61\n\x0cReportHealth\x12&.depot.buildkit.v1.ReportHealthRequest\x1a\'.depot.buildkit.v1.ReportHealthResponse(\x01\x12h\n\x0fReleaseEndpoint\x12).depot.buildkit.v1.ReleaseEndpointRequest\x1a*.depot.buildkit.v1.ReleaseEndpointResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'depot.buildkit.v1.buildkit_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_PLATFORM']._serialized_start=925
  _globals['_PLATFORM']._serialized_end=1001
  _globals['_GETENDPOINTREQUEST']._serialized_start=55
  _globals['_GETENDPOINTREQUEST']._serialized_end=140
  _globals['_GETENDPOINTRESPONSE']._serialized_start=143
  _globals['_GETENDPOINTRESPONSE']._serialized_end=516
  _globals['_GETENDPOINTRESPONSE_PENDINGCONNECTION']._serialized_start=318
  _globals['_GETENDPOINTRESPONSE_PENDINGCONNECTION']._serialized_end=337
  _globals['_GETENDPOINTRESPONSE_ACTIVECONNECTION']._serialized_start=340
  _globals['_GETENDPOINTRESPONSE_ACTIVECONNECTION']._serialized_end=502
  _globals['_RELEASEENDPOINTREQUEST']._serialized_start=518
  _globals['_RELEASEENDPOINTREQUEST']._serialized_end=607
  _globals['_RELEASEENDPOINTRESPONSE']._serialized_start=609
  _globals['_RELEASEENDPOINTRESPONSE']._serialized_end=634
  _globals['_PUBLICCERTIFICATE']._serialized_start=636
  _globals['_PUBLICCERTIFICATE']._serialized_end=669
  _globals['_PRIVATEKEY']._serialized_start=671
  _globals['_PRIVATEKEY']._serialized_end=696
  _globals['_CERTIFICATEPAIR']._serialized_start=698
  _globals['_CERTIFICATEPAIR']._serialized_end=811
  _globals['_REPORTHEALTHREQUEST']._serialized_start=813
  _globals['_REPORTHEALTHREQUEST']._serialized_end=899
  _globals['_REPORTHEALTHRESPONSE']._serialized_start=901
  _globals['_REPORTHEALTHRESPONSE']._serialized_end=923
  _globals['_BUILDKITSERVICE']._serialized_start=1004
  _globals['_BUILDKITSERVICE']._serialized_end=1322
# @@protoc_insertion_point(module_scope)
