# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: depot/core/v1/project.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x64\x65pot/core/v1/project.proto\x12\rdepot.core.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe4\x01\n\x07Project\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x11\n\tregion_id\x18\x04 \x01(\t\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x63\x61\x63he_policy\x18\x06 \x01(\x0b\x32\x1a.depot.core.v1.CachePolicy\x12)\n\x08hardware\x18\x07 \x01(\x0e\x32\x17.depot.core.v1.Hardware\"\x15\n\x13ListProjectsRequest\"@\n\x14ListProjectsResponse\x12(\n\x08projects\x18\x01 \x03(\x0b\x32\x16.depot.core.v1.Project\"\'\n\x11GetProjectRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\"=\n\x12GetProjectResponse\x12\'\n\x07project\x18\x01 \x01(\x0b\x32\x16.depot.core.v1.Project\"\xee\x01\n\x14\x43reateProjectRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1c\n\x0forganization_id\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x11\n\tregion_id\x18\x03 \x01(\t\x12\x35\n\x0c\x63\x61\x63he_policy\x18\x04 \x01(\x0b\x32\x1a.depot.core.v1.CachePolicyH\x01\x88\x01\x01\x12.\n\x08hardware\x18\x05 \x01(\x0e\x32\x17.depot.core.v1.HardwareH\x02\x88\x01\x01\x42\x12\n\x10_organization_idB\x0f\n\r_cache_policyB\x0b\n\t_hardware\"@\n\x15\x43reateProjectResponse\x12\'\n\x07project\x18\x01 \x01(\x0b\x32\x16.depot.core.v1.Project\"\xf1\x01\n\x14UpdateProjectRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x11\n\x04name\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tregion_id\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x35\n\x0c\x63\x61\x63he_policy\x18\x04 \x01(\x0b\x32\x1a.depot.core.v1.CachePolicyH\x02\x88\x01\x01\x12.\n\x08hardware\x18\x05 \x01(\x0e\x32\x17.depot.core.v1.HardwareH\x03\x88\x01\x01\x42\x07\n\x05_nameB\x0c\n\n_region_idB\x0f\n\r_cache_policyB\x0b\n\t_hardware\"@\n\x15UpdateProjectResponse\x12\'\n\x07project\x18\x01 \x01(\x0b\x32\x16.depot.core.v1.Project\"*\n\x14\x44\x65leteProjectRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\"\x17\n\x15\x44\x65leteProjectResponse\")\n\x13ResetProjectRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\"\x16\n\x14ResetProjectResponse\"]\n\x0b\x43\x61\x63hePolicy\x12\x1b\n\nkeep_bytes\x18\x01 \x01(\x03\x42\x02\x18\x01H\x00\x88\x01\x01\x12\x11\n\tkeep_days\x18\x02 \x01(\x05\x12\x0f\n\x07keep_gb\x18\x03 \x01(\x05\x42\r\n\x0b_keep_bytes\".\n\x18ListTrustPoliciesRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\"O\n\x19ListTrustPoliciesResponse\x12\x32\n\x0etrust_policies\x18\x01 \x03(\x0b\x32\x1a.depot.core.v1.TrustPolicy\"\xe0\x01\n\x15\x41\x64\x64TrustPolicyRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x39\n\tbuildkite\x18\x02 \x01(\x0b\x32$.depot.core.v1.TrustPolicy.BuildkiteH\x00\x12\x37\n\x08\x63ircleci\x18\x03 \x01(\x0b\x32#.depot.core.v1.TrustPolicy.CircleCIH\x00\x12\x33\n\x06github\x18\x04 \x01(\x0b\x32!.depot.core.v1.TrustPolicy.GitHubH\x00\x42\n\n\x08provider\"J\n\x16\x41\x64\x64TrustPolicyResponse\x12\x30\n\x0ctrust_policy\x18\x01 \x01(\x0b\x32\x1a.depot.core.v1.TrustPolicy\"G\n\x18RemoveTrustPolicyRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x17\n\x0ftrust_policy_id\x18\x02 \x01(\t\"\x1b\n\x19RemoveTrustPolicyResponse\"\x8f\x03\n\x0bTrustPolicy\x12\x17\n\x0ftrust_policy_id\x18\x01 \x01(\t\x12\x39\n\tbuildkite\x18\x02 \x01(\x0b\x32$.depot.core.v1.TrustPolicy.BuildkiteH\x00\x12\x37\n\x08\x63ircleci\x18\x03 \x01(\x0b\x32#.depot.core.v1.TrustPolicy.CircleCIH\x00\x12\x33\n\x06github\x18\x04 \x01(\x0b\x32!.depot.core.v1.TrustPolicy.GitHubH\x00\x1a\x36\n\x06GitHub\x12\x18\n\x10repository_owner\x18\x01 \x01(\t\x12\x12\n\nrepository\x18\x02 \x01(\t\x1a;\n\x08\x43ircleCI\x12\x19\n\x11organization_uuid\x18\x01 \x01(\t\x12\x14\n\x0cproject_uuid\x18\x02 \x01(\t\x1a=\n\tBuildkite\x12\x19\n\x11organization_slug\x18\x01 \x01(\t\x12\x15\n\rpipeline_slug\x18\x02 \x01(\tB\n\n\x08provider\"\'\n\x11ListTokensRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\"}\n\x12ListTokensResponse\x12\x37\n\x06tokens\x18\x01 \x03(\x0b\x32\'.depot.core.v1.ListTokensResponse.Token\x1a.\n\x05Token\x12\x10\n\x08token_id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"=\n\x12\x43reateTokenRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"7\n\x13\x43reateTokenResponse\x12\x10\n\x08token_id\x18\x01 \x01(\t\x12\x0e\n\x06secret\x18\x02 \x01(\t\";\n\x12UpdateTokenRequest\x12\x10\n\x08token_id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"\x15\n\x13UpdateTokenResponse\"&\n\x12\x44\x65leteTokenRequest\x12\x10\n\x08token_id\x18\x01 \x01(\t\"\x15\n\x13\x44\x65leteTokenResponse*\x98\x01\n\x08Hardware\x12\x18\n\x14HARDWARE_UNSPECIFIED\x10\x00\x12\x12\n\x0eHARDWARE_16X32\x10\x01\x12\x10\n\x0cHARDWARE_4X4\x10\x02\x12\x10\n\x0cHARDWARE_8X8\x10\x03\x12\x11\n\rHARDWARE_8X16\x10\x04\x12\x12\n\x0eHARDWARE_32X64\x10\x05\x12\x13\n\x0fHARDWARE_64X128\x10\x06\x32\xc7\t\n\x0eProjectService\x12Y\n\x0cListProjects\x12\".depot.core.v1.ListProjectsRequest\x1a#.depot.core.v1.ListProjectsResponse\"\x00\x12S\n\nGetProject\x12 .depot.core.v1.GetProjectRequest\x1a!.depot.core.v1.GetProjectResponse\"\x00\x12\\\n\rCreateProject\x12#.depot.core.v1.CreateProjectRequest\x1a$.depot.core.v1.CreateProjectResponse\"\x00\x12\\\n\rUpdateProject\x12#.depot.core.v1.UpdateProjectRequest\x1a$.depot.core.v1.UpdateProjectResponse\"\x00\x12\\\n\rDeleteProject\x12#.depot.core.v1.DeleteProjectRequest\x1a$.depot.core.v1.DeleteProjectResponse\"\x00\x12Y\n\x0cResetProject\x12\".depot.core.v1.ResetProjectRequest\x1a#.depot.core.v1.ResetProjectResponse\"\x00\x12h\n\x11ListTrustPolicies\x12\'.depot.core.v1.ListTrustPoliciesRequest\x1a(.depot.core.v1.ListTrustPoliciesResponse\"\x00\x12_\n\x0e\x41\x64\x64TrustPolicy\x12$.depot.core.v1.AddTrustPolicyRequest\x1a%.depot.core.v1.AddTrustPolicyResponse\"\x00\x12h\n\x11RemoveTrustPolicy\x12\'.depot.core.v1.RemoveTrustPolicyRequest\x1a(.depot.core.v1.RemoveTrustPolicyResponse\"\x00\x12S\n\nListTokens\x12 .depot.core.v1.ListTokensRequest\x1a!.depot.core.v1.ListTokensResponse\"\x00\x12V\n\x0b\x43reateToken\x12!.depot.core.v1.CreateTokenRequest\x1a\".depot.core.v1.CreateTokenResponse\"\x00\x12V\n\x0bUpdateToken\x12!.depot.core.v1.UpdateTokenRequest\x1a\".depot.core.v1.UpdateTokenResponse\"\x00\x12V\n\x0b\x44\x65leteToken\x12!.depot.core.v1.DeleteTokenRequest\x1a\".depot.core.v1.DeleteTokenResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'depot.core.v1.project_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_CACHEPOLICY'].fields_by_name['keep_bytes']._loaded_options = None
  _globals['_CACHEPOLICY'].fields_by_name['keep_bytes']._serialized_options = b'\030\001'
  _globals['_HARDWARE']._serialized_start=2723
  _globals['_HARDWARE']._serialized_end=2875
  _globals['_PROJECT']._serialized_start=80
  _globals['_PROJECT']._serialized_end=308
  _globals['_LISTPROJECTSREQUEST']._serialized_start=310
  _globals['_LISTPROJECTSREQUEST']._serialized_end=331
  _globals['_LISTPROJECTSRESPONSE']._serialized_start=333
  _globals['_LISTPROJECTSRESPONSE']._serialized_end=397
  _globals['_GETPROJECTREQUEST']._serialized_start=399
  _globals['_GETPROJECTREQUEST']._serialized_end=438
  _globals['_GETPROJECTRESPONSE']._serialized_start=440
  _globals['_GETPROJECTRESPONSE']._serialized_end=501
  _globals['_CREATEPROJECTREQUEST']._serialized_start=504
  _globals['_CREATEPROJECTREQUEST']._serialized_end=742
  _globals['_CREATEPROJECTRESPONSE']._serialized_start=744
  _globals['_CREATEPROJECTRESPONSE']._serialized_end=808
  _globals['_UPDATEPROJECTREQUEST']._serialized_start=811
  _globals['_UPDATEPROJECTREQUEST']._serialized_end=1052
  _globals['_UPDATEPROJECTRESPONSE']._serialized_start=1054
  _globals['_UPDATEPROJECTRESPONSE']._serialized_end=1118
  _globals['_DELETEPROJECTREQUEST']._serialized_start=1120
  _globals['_DELETEPROJECTREQUEST']._serialized_end=1162
  _globals['_DELETEPROJECTRESPONSE']._serialized_start=1164
  _globals['_DELETEPROJECTRESPONSE']._serialized_end=1187
  _globals['_RESETPROJECTREQUEST']._serialized_start=1189
  _globals['_RESETPROJECTREQUEST']._serialized_end=1230
  _globals['_RESETPROJECTRESPONSE']._serialized_start=1232
  _globals['_RESETPROJECTRESPONSE']._serialized_end=1254
  _globals['_CACHEPOLICY']._serialized_start=1256
  _globals['_CACHEPOLICY']._serialized_end=1349
  _globals['_LISTTRUSTPOLICIESREQUEST']._serialized_start=1351
  _globals['_LISTTRUSTPOLICIESREQUEST']._serialized_end=1397
  _globals['_LISTTRUSTPOLICIESRESPONSE']._serialized_start=1399
  _globals['_LISTTRUSTPOLICIESRESPONSE']._serialized_end=1478
  _globals['_ADDTRUSTPOLICYREQUEST']._serialized_start=1481
  _globals['_ADDTRUSTPOLICYREQUEST']._serialized_end=1705
  _globals['_ADDTRUSTPOLICYRESPONSE']._serialized_start=1707
  _globals['_ADDTRUSTPOLICYRESPONSE']._serialized_end=1781
  _globals['_REMOVETRUSTPOLICYREQUEST']._serialized_start=1783
  _globals['_REMOVETRUSTPOLICYREQUEST']._serialized_end=1854
  _globals['_REMOVETRUSTPOLICYRESPONSE']._serialized_start=1856
  _globals['_REMOVETRUSTPOLICYRESPONSE']._serialized_end=1883
  _globals['_TRUSTPOLICY']._serialized_start=1886
  _globals['_TRUSTPOLICY']._serialized_end=2285
  _globals['_TRUSTPOLICY_GITHUB']._serialized_start=2095
  _globals['_TRUSTPOLICY_GITHUB']._serialized_end=2149
  _globals['_TRUSTPOLICY_CIRCLECI']._serialized_start=2151
  _globals['_TRUSTPOLICY_CIRCLECI']._serialized_end=2210
  _globals['_TRUSTPOLICY_BUILDKITE']._serialized_start=2212
  _globals['_TRUSTPOLICY_BUILDKITE']._serialized_end=2273
  _globals['_LISTTOKENSREQUEST']._serialized_start=2287
  _globals['_LISTTOKENSREQUEST']._serialized_end=2326
  _globals['_LISTTOKENSRESPONSE']._serialized_start=2328
  _globals['_LISTTOKENSRESPONSE']._serialized_end=2453
  _globals['_LISTTOKENSRESPONSE_TOKEN']._serialized_start=2407
  _globals['_LISTTOKENSRESPONSE_TOKEN']._serialized_end=2453
  _globals['_CREATETOKENREQUEST']._serialized_start=2455
  _globals['_CREATETOKENREQUEST']._serialized_end=2516
  _globals['_CREATETOKENRESPONSE']._serialized_start=2518
  _globals['_CREATETOKENRESPONSE']._serialized_end=2573
  _globals['_UPDATETOKENREQUEST']._serialized_start=2575
  _globals['_UPDATETOKENREQUEST']._serialized_end=2634
  _globals['_UPDATETOKENRESPONSE']._serialized_start=2636
  _globals['_UPDATETOKENRESPONSE']._serialized_end=2657
  _globals['_DELETETOKENREQUEST']._serialized_start=2659
  _globals['_DELETETOKENREQUEST']._serialized_end=2697
  _globals['_DELETETOKENRESPONSE']._serialized_start=2699
  _globals['_DELETETOKENRESPONSE']._serialized_end=2720
  _globals['_PROJECTSERVICE']._serialized_start=2878
  _globals['_PROJECTSERVICE']._serialized_end=4101
# @@protoc_insertion_point(module_scope)
